#! /usr/bin/python
from OpenGL.GL import *
from OpenGL.GLUT import *
from OpenGL.GLU import *

window = 0  # window handler                                         
width, height = 480, 320 # window size
angle = 0

def tick(t):
    global angle
    angle += 1
    glutTimerFunc(100, tick, 0)
    glutPostRedisplay()
    
    
def draw():
    global angle
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)
    glViewport(0, 0, width, height)
    glMatrixMode(GL_PROJECTION)
    glLoadIdentity()

# The glFrustum turns on perspective projection
# Last two parameters define near and far clipping planes. They must be positive.
    glFrustum(-width/50, width/50, -height/50, height/50, 10.0, 1000.0)
    glMatrixMode (GL_MODELVIEW)
    glLoadIdentity()

# Since we use perspective projection and center of projection is in 0,0,0 point,
# we have to move object that it was a bit away from that point.
    glTranslatef(0.0, 0.0, -300)
    
    glRotatef(angle, 1.0, 0.0, 0.0)
    glRotatef(2*angle, 1.0, 1.0, 0.0)
    
    coordinates = [[0.58,0.58,0.58],
		   [0.58,0.58,-0.58],
		   [0.58,-0.58,-0.58],
		   [0.58,-0.58,0.58],
		   [-0.58,0.58,0.58],
		   [-0.58,0.58,-0.58],
		   [-0.58,-0.58,-0.58],
		   [-0.58,-0.58,0.58]]
    
    facets = [[3,2,1,0],
	      [0,1,5,4],
	      [5,1,2,6],
	      [7,6,2,3],
	      [0,4,7,3],
	      [4,5,6,7]]
    
    normals = [[1.0, 0.0, 0.0],
	       [0.0, 1.0, 0.0],
	       [0.0, 0.0, -1.0],
	       [0.0, -1.0, 0.0],
	       [0.0, 0.0, 1.0],
	       [-1.0, 0.0, 0.0]]

# This fragment renders a cube with a single normal per facet
#    glBegin(GL_QUADS)
#    glColor3f(0.5, 0.2, 0.8)
#    for facet in range(0, 6):
#        glNormal3f(normals[facet][0], normals[facet][1], normals[facet][2])
#        for vertex in range(0, 4):
#            glVertex3f(100*coordinates[facets[facet][vertex]][0], 
#                       100*coordinates[facets[facet][vertex]][1], 
#                       100*coordinates[facets[facet][vertex]][2])
#    glEnd()
    
# This fragment renders a cube with a Gouraud trick
# The "normal" vector is set per vertex and interpolated on a facet surface
    glBegin(GL_QUADS)
    glColor3f(0.5, 0.2, 0.8)
    for facet in range(0, 6):
        for vertex in range(0, 4):
            glNormal3f(coordinates[facets[facet][vertex]][0], 
                       coordinates[facets[facet][vertex]][1], 
                       coordinates[facets[facet][vertex]][2])
            glVertex3f(100*coordinates[facets[facet][vertex]][0], 
                       100*coordinates[facets[facet][vertex]][1], 
                       100*coordinates[facets[facet][vertex]][2])
    glEnd()
    
    
    # show what was rendered in a buffer
    glutSwapBuffers() 
  


# --------------   program starts here   -----------------------

# initialize OpenGL by GLUT (openGl Utility Toolkit) library
glutInit()  
glutInitDisplayMode(GLUT_RGBA | GLUT_DOUBLE | GLUT_ALPHA | GLUT_DEPTH)

# create window for graphiccs
glutInitWindowSize(width, height) 
glutInitWindowPosition(0, 0)
window = glutCreateWindow("IP&CG Lecture")

# this enables specified computations in openGl
glEnable(GL_DEPTH_TEST)
glEnable(GL_CULL_FACE)
glEnable(GL_LIGHTING)
glEnable(GL_NORMALIZE)
glEnable(GL_AUTO_NORMAL)

# defining light properties
ambientLight = [0.1, 0.1, 0.1, 1.0 ]
diffuseLight = [0.9, 0.9, 0.9, 1.0 ]
specular = [ 1.0, 1.0, 1.0, 1.0]
lightPos = [ -250.0, 1000.0, 1000.0, 1.0 ]
glLightModelfv(GL_LIGHT_MODEL_AMBIENT,ambientLight)
glLightfv(GL_LIGHT0,GL_AMBIENT,ambientLight)
glLightfv(GL_LIGHT0,GL_DIFFUSE,diffuseLight)
glLightfv(GL_LIGHT0,GL_SPECULAR,specular)
glLightfv(GL_LIGHT0,GL_POSITION,lightPos)
glEnable(GL_LIGHT0)

# specifies material properties
specref =  [ 0.6, 0.6, 0.6, 1.0 ]
glEnable(GL_COLOR_MATERIAL)
glColorMaterial(GL_FRONT, GL_AMBIENT_AND_DIFFUSE)
glMaterialfv(GL_FRONT, GL_SPECULAR,specref)
glMateriali(GL_FRONT,GL_SHININESS,64)

# set callback for drawing event
glutDisplayFunc(draw) 

# set timer callback function 
glutTimerFunc(100, tick, 0)

# start the main loop (wait for system evants)
glutMainLoop() 