#! /usr/bin/python
from OpenGL.GL import *
from OpenGL.GLUT import *
from OpenGL.GLU import *

window = 0  # window handler                                         
width, height = 480, 320 # window size
angle = 0

def tick(t):
    global angle
    angle += 1
    glutTimerFunc(100, tick, 0)
    glutPostRedisplay()
    
    
def draw():
    global angle
    # set transformation, projection and viewport
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)
    glViewport(0, 0, width, height)
    glMatrixMode(GL_PROJECTION)
    glLoadIdentity()
    
# The glOrtho sets orthonormal projection. There is no perspective effect.
# Last two parameters define nearer and farther clipping planes. 
# The viewing frustum in this case is rectangular parallelepiped (cuboid). 
# In this case object can be located around 0,0,0 location
    glOrtho(-width/2, width/2, -height/2, height/2, -100.0, 100.0)
# Optionally one can use perspective projection set by glFrustum function.
# As the 0,0,0 point becomes a center of projection in this case, all objects 
# must be moved away from 0,0,0 location by means of glTranslatef function. 
        
    glMatrixMode (GL_MODELVIEW)
    glLoadIdentity()
 
    # this will compute rotation on transformation matrix
    glRotatef(angle, 1.0, 0.0, 0.0)
    glRotatef(2*angle, 1.0, 1.0, 0.0)
    
    # render (draw in 3D) something
    glBegin(GL_TRIANGLES)
    glColor3f(0.2, 0.2, 0.8)
    glNormal3f(0.58, 0.58, 0.58)
    glVertex3f(0.0, 100.0, 0.0)
    glVertex3f(100.0, 0.0, 0.0)
    glVertex3f(0.0, 0.0, 100.0)

    glColor3f(0.7, 0.7, 0.2)
    glNormal3f(0.0, 0.0, -1.0)
    glVertex3f(0.0, 100.0, 0.0)
    glVertex3f(0.0, 0.0, 0.0)
    glVertex3f(100.0, 0.0, 0.0)

    glColor3f(0.7, 0.2, 0.7)
    glNormal3f(-1.0, 0.0, 0.0)
    glVertex3f(0.0, 100.0, 0.0)
    glVertex3f(0.0, 0.0, 100.0)
    glVertex3f(0.0, 0.0, 0.0)

    glColor3f(0.2, 0.7, 0.7)
    glNormal3f(0.0, -1.0, 0.0)
    glVertex3f(0.0, 0.0, 100.0)
    glVertex3f(100.0, 0.0, 0.0)
    glVertex3f(0.0, 0.0, 0.0)
    glEnd()
    
    # show what was rendered in a buffer
    glutSwapBuffers() 
  


# --------------   program starts here   -----------------------

# initialize OpenGL by GLUT (openGl Utility Toolkit) library
glutInit()  
glutInitDisplayMode(GLUT_RGBA | GLUT_DOUBLE | GLUT_ALPHA | GLUT_DEPTH)

# create window for graphiccs
glutInitWindowSize(width, height) 
glutInitWindowPosition(0, 0)
window = glutCreateWindow("IP&CG Lecture")

# this enables specified computations in openGl
glEnable(GL_DEPTH_TEST)
glEnable(GL_CULL_FACE)
glEnable(GL_LIGHTING)
glEnable(GL_NORMALIZE)
glEnable(GL_AUTO_NORMAL)

# defining light properties
ambientLight = [0.1, 0.1, 0.1, 1.0 ]
diffuseLight = [0.9, 0.9, 0.9, 1.0 ]
specular = [ 1.0, 1.0, 1.0, 1.0]
lightPos = [ -250.0, 1000.0, 1000.0, 1.0 ]
glLightModelfv(GL_LIGHT_MODEL_AMBIENT,ambientLight)
glLightfv(GL_LIGHT0,GL_AMBIENT,ambientLight)
glLightfv(GL_LIGHT0,GL_DIFFUSE,diffuseLight)
glLightfv(GL_LIGHT0,GL_SPECULAR,specular)
glLightfv(GL_LIGHT0,GL_POSITION,lightPos)
glEnable(GL_LIGHT0)

# specifies material properties
specref =  [ 0.6, 0.6, 0.6, 1.0 ]
glEnable(GL_COLOR_MATERIAL)
glColorMaterial(GL_FRONT, GL_AMBIENT_AND_DIFFUSE)
glMaterialfv(GL_FRONT, GL_SPECULAR,specref)
glMateriali(GL_FRONT,GL_SHININESS,64)

# set callback for drawing event
glutDisplayFunc(draw) 

# set timer callback function 
glutTimerFunc(100, tick, 0)

# start the main loop (wait for system evants)
glutMainLoop() 